@@ -7,15 +7,17 @@ gid=$2
 
 cd /tmp
 
-mkdir -p build && cd build
-MOD_PREFIX=$PWD/install
-CXXFLAGS="-Wall -Wextra -Wpedantic -Wshadow -Werror -DPERSALYS_NSIS" ${ARCH}-w64-mingw32-cmake -DUSE_SPHINX=OFF -DUSE_SALOME=OFF \
+MOD_PREFIX=$PWD/build/install
+CXXFLAGS="-Wall -Wextra -Wpedantic -Wshadow -Werror" ${ARCH}-w64-mingw32-cmake \
   -DCMAKE_INSTALL_PREFIX=${MOD_PREFIX} \
+  -DCMAKE_LINKER_TYPE=LLD \
   -DPython_INCLUDE_DIR=${MINGW_PREFIX}/include/python${PYMAJMIN} \
   -DPython_LIBRARY=${MINGW_PREFIX}/lib/libpython${PYMAJMIN}.dll.a \
   -DPython_EXECUTABLE=/usr/bin/${ARCH}-w64-mingw32-python${PYMAJMIN}-bin \
   -DSWIG_COMPILE_FLAGS="-Wno-unused-parameter -Wno-shadow" \
-  -DCMAKE_UNITY_BUILD=ON -DCMAKE_UNITY_BUILD_BATCH_SIZE=32 /io
+  -DPERSALYS_BUILD_NSIS=ON \
+  -DCMAKE_UNITY_BUILD=ON -DCMAKE_UNITY_BUILD_BATCH_SIZE=32 -B build /io
+cd build
 make install
 ${ARCH}-w64-mingw32-strip --strip-unneeded ${MOD_PREFIX}/bin/*.dll ${MOD_PREFIX}/Lib/site-packages/persalys/*.pyd
 make tests
@@ -40,15 +42,15 @@ curl -fSsL https://anaconda.org/conda-forge/vs2015_runtime/14.16.27012/download/
 cp -r /usr/${ARCH}-w64-mingw32/Lib/site-packages/openturns Lib/site-packages
 cp /usr/${ARCH}-w64-mingw32/bin/*.dll Lib/site-packages/openturns
 cp /usr/${ARCH}-w64-mingw32/etc/openturns/openturns.conf Lib/site-packages/openturns
-rm Lib/site-packages/openturns/{libvtk,libboost,libLLVM,Qt,python}*.dll
+rm Lib/site-packages/openturns/{libvtk,libboost,Qt,python}*.dll
 cp -rv /usr/${ARCH}-w64-mingw32/Lib/site-packages/otmorris Lib/site-packages
 
-curl -fSsL https://anaconda.org/conda-forge/pyfmi/2.13.0/download/win-64/pyfmi-2.13.0-py311he736701_4.conda | bsdtar -x && tar -xf pkg-pyfmi-2.13.0-py311he736701_4.tar.zst
-curl -fSsL https://anaconda.org/conda-forge/assimulo/3.5.1/download/win-64/assimulo-3.5.1-py311h4006923_2.conda | bsdtar -x && tar -xf pkg-assimulo-3.5.1-py311h4006923_2.tar.zst
-curl -fSsL https://anaconda.org/conda-forge/sundials/7.0.0/download/win-64/sundials-7.0.0-h62746c2_4.conda | bsdtar -x && tar -xf pkg-sundials-7.0.0-h62746c2_4.tar.zst
+curl -fSsL https://anaconda.org/conda-forge/pyfmi/2.17.0/download/win-64/pyfmi-2.17.0-py313h8e081ca_0.conda | bsdtar -x && tar -xf pkg-pyfmi-2.17.0-py313h8e081ca_0.tar.zst
+curl -fSsL https://anaconda.org/conda-forge/assimulo/3.7.0/download/win-64/assimulo-3.7.0-py313he6753d5_0.conda | bsdtar -x && tar -xf pkg-assimulo-3.7.0-py313he6753d5_0.tar.zst
+curl -fSsL https://anaconda.org/conda-forge/sundials/7.3.0/download/win-64/sundials-7.3.0-hdaf6363_0.conda | bsdtar -x && tar -xf pkg-sundials-7.3.0-hdaf6363_0.tar.zst
 cp -r Library/bin/*.dll . && rm -r Library info pkg-*.zst info-*.zst
 cd Lib
-curl -fSsL https://anaconda.org/conda-forge/otfmi/0.16.4/download/noarch/otfmi-0.16.4-pyhff2d567_0.conda | bsdtar -x && tar -xf pkg-otfmi-0.16.4-pyhff2d567_0.tar.zst
+curl -fSsL https://anaconda.org/conda-forge/otfmi/0.16.6/download/noarch/otfmi-0.16.6-pyhd8ed1ab_0.conda | bsdtar -x && tar -xf pkg-otfmi-0.16.6-pyhd8ed1ab_0.tar.zst
 cd site-packages
 curl -fsSL https://pypi.io/packages/py3/p/pip/pip-24.1.1-py3-none-any.whl | bsdtar -xf-
 curl -fsSL https://pypi.io/packages/py2.py3/w/wheel/wheel-0.34.2-py2.py3-none-any.whl | bsdtar -xf-
@@ -57,14 +59,14 @@ curl -fSsL https://pypi.io/packages/py2.py3/p/pytz/pytz-2021.3-py2.py3-none-any.
 curl -fSsL https://pypi.io/packages/py2.py3/p/python_dateutil/python_dateutil-2.8.2-py2.py3-none-any.whl | bsdtar -xf-
 curl -fSsL https://pypi.io/packages/py3/d/dill/dill-0.3.8-py3-none-any.whl | bsdtar -xf-
 curl -fsSL https://pypi.io/packages/py3/s/setuptools/setuptools-49.2.0-py3-none-any.whl | bsdtar -xf-
-curl -fsSL https://pypi.io/packages/cp311/n/numpy/numpy-1.26.4-cp311-cp311-win_amd64.whl | bsdtar -xf-
-curl -fsSL https://pypi.io/packages/cp311/s/scipy/scipy-1.13.1-cp311-cp311-win_amd64.whl | bsdtar -xf-
-curl -fsSL https://pypi.io/packages/cp311/p/pandas/pandas-2.2.2-cp311-cp311-win_amd64.whl | bsdtar -xf-
-curl -fSsL https://pypi.io/packages/py2.py3/o/openpyxl/openpyxl-3.1.2-py2.py3-none-any.whl | bsdtar -xf-
+curl -fsSL https://pypi.io/packages/cp313/n/numpy/numpy-2.2.4-cp313-cp313-win_amd64.whl | bsdtar -xf-
+curl -fsSL https://pypi.io/packages/cp313/s/scipy/scipy-1.15.2-cp313-cp313-win_amd64.whl | bsdtar -xf-
+curl -fsSL https://pypi.io/packages/cp313/p/pandas/pandas-2.2.3-cp313-cp313-win_amd64.whl | bsdtar -xf-
+curl -fSsL https://pypi.io/packages/py2.py3/o/openpyxl/openpyxl-3.1.5-py2.py3-none-any.whl | bsdtar -xf-
 curl -fSsL https://pypi.io/packages/py3/e/et_xmlfile/et_xmlfile-1.1.0-py3-none-any.whl | bsdtar -xf-
 curl -fSsL https://pypi.io/packages/py3/j/jinja2/jinja2-3.1.4-py3-none-any.whl | bsdtar -xf-
-curl -fsSL https://pypi.io/packages/cp311/m/markupsafe/MarkupSafe-2.1.5-cp311-cp311-win_amd64.whl | bsdtar -xf-
-curl -fSsL https://pypi.io/packages/py3/p/pythonfmu/pythonfmu-0.6.3-py3-none-any.whl | bsdtar -xf-
+curl -fsSL https://pypi.io/packages/cp313/m/markupsafe/MarkupSafe-3.0.2-cp313-cp313-win_amd64.whl | bsdtar -xf-
+curl -fSsL https://pypi.io/packages/py3/p/pythonfmu/pythonfmu-0.6.6-py3-none-any.whl | bsdtar -xf-
 curl -fSsL https://pypi.io/packages/py3/n/nopip/nopip-0.2.2-py3-none-any.whl | bsdtar -xf-
 cd ../..
 mkdir Scripts && echo -e 'import sys\nfrom pip import main\nsys.exit(main())\n' > Scripts/pip.py && echo -e 'python %~dp0pip.py %*' > Scripts/pip.bat
