@@ -2,7 +2,7 @@
 /**
  *  @brief Inference analysis
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,10 +24,6 @@
 
 #include <openturns/DistributionFactory.hxx>
 #include <openturns/NormalCopulaFactory.hxx>
-#if OPENTURNS_VERSION < 102400
-#include <openturns/IndependentCopulaFactory.hxx>
-#include <openturns/StudentCopulaFactory.hxx>
-#endif
 #include <openturns/Combinations.hxx>
 #include <openturns/VisualTest.hxx>
 #include <openturns/PersistentObjectFactory.hxx>
@@ -83,6 +79,10 @@ CopulaInferenceAnalysis::CopulaInferenceAnalysis(const String &name, const Desig
 
 Collection<Description> CopulaInferenceAnalysis::buildDefaultVariablesGroups()
 {
+  Collection<Description> groups;
+  if (!designOfExperiment_.getSample().getSize())
+    return groups;
+
   // Spearman correlation matrix
   CorrelationMatrix C(designOfExperiment_.getSample().computeSpearmanCorrelation());
 
@@ -95,7 +95,6 @@ Collection<Description> CopulaInferenceAnalysis::buildDefaultVariablesGroups()
       C(i, j) = (std::abs(C(i, j)) > epsilon) ? 1.0 : 0.0;
 
   // find groups of dependent variables
-  Collection<Description> groups;
   Collection<Indices> components = ConnectedComponents(C);
 
   for (UnsignedInteger i = 0; i < components.getSize(); ++i)
@@ -156,7 +155,6 @@ CopulaInferenceAnalysis* CopulaInferenceAnalysis::clone() const
   return new CopulaInferenceAnalysis(*this);
 }
 
-
 CopulaInferenceAnalysis::DistributionFactoryCollection CopulaInferenceAnalysis::getDistributionsFactories(const Description& variablesNames) const
 {
   const Description setOfVariables(getSortedVariablesNames(variablesNames));
@@ -304,18 +302,7 @@ void CopulaInferenceAnalysis::launch()
                                << ex.what()
                                << "\n";
         // set fittingTestResult
-#if OPENTURNS_VERSION < 102400
-        if (distributionName == "Independent")
-          inferenceSetResult.testedDistributions_.add(IndependentCopulaFactory().build());
-        else if (distributionName == "Student")
-          inferenceSetResult.testedDistributions_.add(StudentCopulaFactory().build());
-        else
-        {
-          inferenceSetResult.testedDistributions_.add(DistributionFactory::GetByName(distributionName+"CopulaFactory").build());
-        }
-#else
-        inferenceSetResult.testedDistributions_.add(DistributionFactory::GetByName(distributionName+"CopulaFactory").build());
-#endif
+        inferenceSetResult.testedDistributions_.add(DistributionFactory::GetByName(distributionName + "CopulaFactory").build());
 
         ProcessSample kendallPlotDataCollection;
         inferenceSetResult.bicResults_.add(SpecFunc::MaxScalar);
