@@ -2,7 +2,7 @@
 /**
  *  @brief Intermediate coupling step
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -117,7 +117,7 @@ String CouplingPhysicalModel::getStepsMacro(const String & offset) const
         oss << offset << "output_file" << j
             << ".setVariables("
             << Parameters::GetOTDescriptionStr(outputFile.getVariableNames())
-            << ", " << Parameters::GetOTDescriptionStr(EscapeSpecialCharacters(outputFile.getTokens()))
+            << ", " << Parameters::GetOTDescriptionStr(outputFile.getTokens())
             << ", " << Parameters::GetOTPointStr(outputFile.getSkipTokens())
             << ", " << Parameters::GetOTPointStr(outputFile.getSkipLines())
             << ", " << Parameters::GetOTPointStr(outputFile.getSkipColumns()) << ")\n";
@@ -270,22 +270,23 @@ void CouplingPhysicalModel::updateCode()
   code << "                continue\n";
   code << "            outfile = os.path.join(workdir, output_file.getPath())\n";
   code << "            for varname, token, skip_tok, skip_line, skip_col in zip(output_file.getVariableNames(), output_file.getTokens(), output_file.getSkipTokens(), output_file.getSkipLines(), output_file.getSkipColumns()):\n";
-  code << "                all_vars[varname] = otct.get_value(outfile, token=token, skip_token=int(skip_tok), skip_line=int(skip_line), skip_col=int(skip_col), encoding=step.getEncoding())\n";
+  code << "                token_esc = re.escape(token)\n";
+  code << "                all_vars[varname] = otct.get_value(outfile, token=token_esc, skip_token=int(skip_tok), skip_line=int(skip_line), skip_col=int(skip_col), encoding=step.getEncoding())\n";
   code << "        if step.getCode():\n";
   code << "            script = step.getCode()\n";
 
-  code << "            regexsearch = re.search('def (\\w*)\\(.*\\):', script)\n";
+  code << "            regexsearch = re.search(r'def (\\w*)\\(.*\\):', script)\n";
   code << "            if regexsearch is not None:\n";
   code << "                script_funcname = regexsearch.group(1)\n";
   code << "            else:\n";
   code << "                raise RuntimeError('Could not find extra processing function name')\n";
 
-  code << "            regexsearch = re.search('def \\w+\\(([\\w, ]+)\\):', script)\n";
+  code << "            regexsearch = re.search(r'def \\w+\\(([\\w, ]+)\\):', script)\n";
   code << "            if regexsearch is not None:\n";
   code << "                script_invars = regexsearch.group(1).replace(' ', '').split(',')\n";
   code << "            else:\n";
   code << "                script_invars = []\n";
-  code << "            regexsearch = re.search('return ([\\w, ]+)', script)\n";
+  code << "            regexsearch = re.search(r'return ([\\w, ]+)', script)\n";
   code << "            if regexsearch is not None:\n";
   code << "                script_outvars = regexsearch.group(1).replace(' ', '').split(',')\n";
   code << "            else:\n";
