@@ -2,7 +2,7 @@
 /**
  *  @brief Helper to build OT distribution
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,8 +36,8 @@ std::vector<String> DistributionDictionary::ContinuousDistributions_ =
 };
 std::vector<String> DistributionDictionary::DiscreteDistributions_ =
 {
-  "Bernoulli", "Geometric", "Binomial", "Hypergeometric", "NegativeBinomial",
-  "Poisson", "Skellam", "UserDefined", "ZipfMandelbrot"
+  "Bernoulli", "Binomial", "Geometric", "Hypergeometric",
+  "Poisson", "Polya", "Skellam", "UserDefined", "ZipfMandelbrot"
 };
 
 
@@ -120,9 +120,9 @@ Distribution DistributionDictionary::BuildDistribution(const String & distributi
 
       return LogUniform(muLog - sqrt(3.0) * sigmaLog, muLog + sqrt(3.0) * sigmaLog);
     }
-    else if (distributionName == "NegativeBinomial")
+    else if (distributionName == "Polya")
     {
-      return NegativeBinomial();
+      return Polya();
     }
     else if (distributionName == "Normal")
     {
