@@ -2,7 +2,7 @@
 /**
  *  @brief MorrisAnalysis
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -173,7 +173,7 @@ void MorrisAnalysis::launch()
 
   // build a Morris experiment
   const UnsignedInteger nbInputs = getPhysicalModel().getInputDimension();
-  MorrisExperimentGrid morris_experiment(Indices(nbInputs, level_), bounds_, trajectoriesNumber_);
+  MorrisExperimentGrid morris_experiment(Indices(nbInputs, level_), trajectoriesNumber_, bounds_);
   morris_experiment.setJumpStep(Indices(nbInputs, std::floor(level_ * 0.5)));
 
   // generate input sample
