@@ -2,7 +2,7 @@
 /**
  *  @brief Multi-objective optimization of a physical model
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,6 +27,7 @@
 #include <openturns/SimulatedAnnealingLHS.hxx>
 #include <openturns/RandomGenerator.hxx>
 #include <openturns/UserDefined.hxx>
+#include <openturns/OptimizationAlgorithm.hxx>
 
 using namespace OT;
 
@@ -80,7 +81,7 @@ Description MultiObjectiveOptimizationAnalysis::GetSolverNames(const Interval& b
 {
   // Dummy function to match a multi objective problem
   Function func = SymbolicFunction(Description::BuildDefault(bounds.getDimension(), "x"),
-                                   Description(bounds.getDimension(), "x0^2"));
+                                   Description(2, "x0^2"));
   OptimizationProblem problem(func, Function(), Function(), bounds);
   if (types.getSize())
     problem.setVariablesType(types);
