@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all physical models
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -591,7 +591,10 @@ Distribution PhysicalModelImplementation::getDistribution() const
   if (!marginals.getSize())
     return Distribution();
 
-  return JointDistribution(marginals, blockIndependentCopula_.getMarginal(copulaMarginals));
+  JointDistribution result(marginals, blockIndependentCopula_.getMarginal(copulaMarginals));
+  // disable parallel generation so that we get identical samples regardless of the block size to benefit from caching
+  result.setParallel(false);
+  return result;
 }
 
 
