@@ -2,7 +2,7 @@
 /**
  *  @brief QObject
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,10 +26,12 @@
 #include "persalys/InferenceAnalysis.hxx"
 #include "persalys/CopulaInferenceAnalysis.hxx"
 #include "persalys/DataAnalysis.hxx"
+#include "persalys/FieldKarhunenLoeveAnalysis.hxx"
 #include "persalys/FieldModelEvaluation.hxx"
 #include "persalys/FieldMonteCarloAnalysis.hxx"
 #include "persalys/MonteCarloAnalysis.hxx"
 #include "persalys/SobolAnalysis.hxx"
+#include "persalys/QuantileAnalysis.hxx"
 #include "persalys/MonteCarloReliabilityAnalysis.hxx"
 #include "persalys/OptimizationAnalysis.hxx"
 #include "persalys/MultiObjectiveOptimizationAnalysis.hxx"
@@ -70,6 +72,8 @@ QString ItemFactory::getParentTitleType(const QString &objectName) const
       return "MetaModelsTitle";
     else if (objectName == "DataModel")
       return "DataModelsTitle";
+    else if (objectName == "DataFieldModel")
+      return "DataFieldModelsTitle";
     else
       return "PhysicalModelsTitle";
   }
@@ -119,6 +123,12 @@ Item * ItemFactory::getTitleItem(const QString &objectName)
       item->setData(QIcon(":/images/dataModel.png"), Qt::DecorationRole);
       item->appendAction(newDataModel_);
     }
+    else if (objectName == "DataFieldModel")
+    {
+      item = new Item(tr("Field data models"), "DataFieldModelsTitle");
+      item->setData(QIcon(":/images/dataModel.png"), Qt::DecorationRole);
+      item->appendAction(newDataFieldModel_);
+    }
     else
     {
       item = new Item(tr("Physical models"), "PhysicalModelsTitle");
@@ -290,7 +300,7 @@ QAction * ItemFactory::createAction(const QString &analysisName, const PhysicalM
     connect(action, &QAction::triggered, [ = ]()
     {
       emit wizardRequested(getParentStudyItem(),
-                           MultiObjectiveOptimizationAnalysis(availableAnalysisName(tr("mo-optimization_")), model));
+                           MultiObjectiveOptimizationAnalysis(availableAnalysisName(tr("multiObjectiveOptimization_")), model));
     });
   }
   else if (analysisName == "Sensitivity")
@@ -375,6 +385,17 @@ QAction * ItemFactory::createAction(const QString &analysisName, const DesignOfE
       newAnalysis("Calibration", doe);
     });
   }
+  else if (analysisName == "QuantileAnalysis")
+  {
+    action = new QAction(QIcon(":/images/sensitivity.png"), tr("Quantile"), this);
+    action->setStatusTip(tr("Create a new quantile analysis"));
+    connect(action, &QAction::triggered, [ = ]()
+    {
+      emit wizardRequested(getParentStudyItem(),
+                           QuantileAnalysis(availableAnalysisName(tr("quantile_")), doe));
+    });
+  }
+
   else
   {
     qDebug() << "Error: In createAction: analysisName " << analysisName << " not recognized.\n";
@@ -400,6 +421,22 @@ QAction * ItemFactory::createAction(const QString &analysisName, const LimitStat
 }
 
 
+QAction * ItemFactory::createAction(const QString &analysisName, const DataFieldModel &dataFieldModel)
+{
+  if (analysisName == "FieldKarhunenLoeveAnalysis")
+  {
+    QAction * action = new QAction(tr("Field data analysis"), this);
+    action->setStatusTip(tr("Analyze data and create a Karhunene-Loeve decomposition"));
+    connect(action, &QAction::triggered, [ = ]() {
+      getParentStudyItem()->getStudy().add(FieldKarhunenLoeveAnalysis(availableAnalysisName(tr("fieldDataAnalysis_")), dataFieldModel));
+    });
+    return action;
+  }
+  qDebug() << "Error: In createAction: analysisName " << analysisName << " not recognized.\n";
+  return 0;
+}
+
+
 QAction * ItemFactory::createAction(const QString &analysisName, const Analysis &analysis)
 {
   if (analysisName == "Metamodel")
