@@ -2,7 +2,7 @@
 /**
  *  @brief QWizardPage to define simulation reliability analysis
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -346,7 +346,7 @@ void CalibrationParametersPage::buildInterface()
   sampleSizeLayout->addWidget(sampleSizeLabel);
   bootStrapSizeSpinBox_ = new UIntSpinBox;
   bootStrapSizeSpinBox_->setMinimum(1);
-  bootStrapSizeSpinBox_->setSingleStep(5);;
+  bootStrapSizeSpinBox_->setSingleStep(5);
   connect(bootstrapCheckBox_, SIGNAL(clicked(bool)), bootStrapSizeSpinBox_, SLOT(setEnabled(bool)));
   sampleSizeLayout->addWidget(bootStrapSizeSpinBox_);
   bootStrapLayout->addLayout(sampleSizeLayout, 1, 1);
