@@ -2,7 +2,7 @@
 /**
  *  @brief QMdiSubWindow for the results of an evaluation of the model
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -78,7 +78,7 @@ CalibrationResultWindow::CalibrationResultWindow(AnalysisItem *item, QWidget *pa
   QVBoxLayout * widgetLayout = new QVBoxLayout(this);
 
   // title
-  widgetLayout->addWidget(new TitleLabel("Calibration", "user_manual/graphical_interface/deterministic_analysis/user_manual_deterministic_analysis.html#calibrationresult"));
+  widgetLayout->addWidget(new TitleLabel(tr("Calibration"), "user_manual/graphical_interface/deterministic_analysis/user_manual_deterministic_analysis.html#calibrationresult"));
 
   // main splitter
   QSplitter * mainWidget = new QSplitter(Qt::Horizontal);
@@ -193,7 +193,7 @@ CalibrationResultWindow::CalibrationResultWindow(AnalysisItem *item, QWidget *pa
 
     pvWidget->setData(pdfSamplePrior, Qt::red);
     pvWidget->setData(pdfSamplePosterior, Qt::green);
-    if (result_.isBayesian())
+    if (result_.getCalibrationResult().isBayesian())
     {
       pvWidget->setRepresentationLabels(QVector<QString>(nbInputs * 2, tr("Prior")).toList(), 0);
       pvWidget->setRepresentationLabels(QVector<QString>(nbInputs * 2, tr("Posterior")).toList(), 1);
@@ -354,7 +354,7 @@ QTabWidget * CalibrationResultWindow::getPredictionTabWidget(const UnsignedInteg
 
   Graph residualPDF(observationsError.drawPDF());
   pvWidget->setData(residualPDF.getDrawables()[0].getData(), Colors_[tr("Data")]);
-  if (result_.isBayesian())
+  if (result_.getCalibrationResult().isBayesian())
     pvWidget->setRepresentationLabels(QStringList() << tr("Normal, hypothesis")
                                       << tr("Normal, hypothesis"));
   else
@@ -380,7 +380,22 @@ QTabWidget * CalibrationResultWindow::getPredictionTabWidget(const UnsignedInteg
 
   chartSetting = new TrajectoriesSettingWidget(pvWidget, labels, this);
 
-  predTabWidget->addTab(new WidgetBoundToDockWidget(pvWidget, chartSetting, this), tr("Residuals"));
+  QWidget *residualsTab = new QWidget;
+  QVBoxLayout *residualsLayout = new QVBoxLayout(residualsTab);
+
+  QWidget *graphContainer = new QWidget;
+  QVBoxLayout *graphLayout = new QVBoxLayout(graphContainer);
+  graphLayout->setContentsMargins(0, 0, 0, 0);
+  graphLayout->addWidget(new WidgetBoundToDockWidget(pvWidget, chartSetting, this));
+  graphContainer->setLayout(graphLayout);
+  residualsLayout->addWidget(graphContainer, 1);
+
+  const double std = result_.getCalibrationResult().getObservationsError().getStandardDeviation()[i];
+  QString stdLabel = tr("Residuals standard deviation (assuming gaussian distribution): σ = %1").arg(std);
+  QLabel * stdLabelWidget = new QLabel(stdLabel);
+  residualsLayout->addWidget(stdLabelWidget);
+
+  predTabWidget->addTab(residualsTab, tr("Residuals"));
 
   // - residuals QQ-plot
 
