@@ -2,7 +2,7 @@
 /**
  *  @brief QWizard for copula inference
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,11 +27,6 @@
 
 #include <openturns/NormalCopulaFactory.hxx>
 
-#if OPENTURNS_VERSION < 102400
-#include <openturns/IndependentCopulaFactory.hxx>
-#include <openturns/StudentCopulaFactory.hxx>
-#endif
-
 #include <QVBoxLayout>
 #include <QPushButton>
 #include <QToolButton>
@@ -195,20 +190,8 @@ void CopulaInferenceWizard::updateDistForVars(const Description& vars, const QSt
   CopulaInferenceAnalysis::DistributionFactoryCollection factories;
   for (int i = 0; i < dist.size(); ++i)
   {
-#if OPENTURNS_VERSION < 102400
-    if (dist[i].contains("Independent"))
-      factories.add(IndependentCopulaFactory());
-    else if (dist[i].contains("Student"))
-      factories.add(StudentCopulaFactory());
-    else
-    {
-      const String distName = TranslationManager::GetCopulaName(dist[i]);
-      factories.add(DistributionFactory::GetByName(distName+"CopulaFactory"));
-    }
-#else
     const String distName = TranslationManager::GetCopulaName(dist[i]);
-    factories.add(DistributionFactory::GetByName(distName+"CopulaFactory"));
-#endif
+    factories.add(DistributionFactory::GetByName(distName + "CopulaFactory"));
   }
   distForVars_[vars] = factories;
 }
