@@ -2,7 +2,7 @@
 /**
  *  @brief QMdiSubWindow for the results of functional chaos
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -104,7 +104,7 @@ void FunctionalChaosResultWindow::buildInterface()
   QTabWidget * tabWidget = new QTabWidget;
 
   // first tab : MOMENTS --------------------------------
-  if (result_.getMean().getSize() == nbOutputs && result_.getVariance().getSize() == nbOutputs)
+  if (result_.getMean().getSize() == nbOutputs && result_.getVariance().getSize() == nbOutputs && result_.getMeanSquaredError().getSize() == nbOutputs)
   {
     QScrollArea * scrollArea = new QScrollArea;
     scrollArea->setWidgetResizable(true);
@@ -116,10 +116,10 @@ void FunctionalChaosResultWindow::buildInterface()
     for (UnsignedInteger outputIndex = 0; outputIndex < nbOutputs; ++outputIndex)
     {
       QStringList namesList;
-      namesList << tr("Residual") << tr("Relative error (%)");
+      namesList << tr("MSE") << tr("R2");
       QStringList valuesList;
-      valuesList << QString::number(result_.getFunctionalChaosResult().getResiduals()[outputIndex]);
-      valuesList << QString::number(100.*result_.getFunctionalChaosResult().getRelativeErrors()[outputIndex]);
+      valuesList << QString::number(result_.getMeanSquaredError()[outputIndex]);
+      valuesList << QString::number(result_.getR2Score()[outputIndex]);
       ParametersTableView * generalTableView = new ParametersTableView(namesList, valuesList, true, true);
       generalStackedWidget->addWidget(generalTableView);
     }
@@ -240,20 +240,18 @@ void FunctionalChaosResultWindow::buildInterface()
       CopyableTableView * tableView = new CopyableTableView;
       tableView->verticalHeader()->hide();
       tableView->horizontalHeader()->hide();
-      CustomStandardItemModel * tableModel = new CustomStandardItemModel(1, 4, tableView);
+      CustomStandardItemModel * tableModel = new CustomStandardItemModel(1, 3, tableView);
       tableView->setModel(tableModel);
 
       // row
       tableModel->setNotEditableHeaderItem(0, 0, tr("Index"));
       tableModel->setNotEditableHeaderItem(0, 1, tr("Multi-indice"));
-      tableModel->setNotEditableHeaderItem(0, 2, tr("Coefficient"));
-      tableModel->setNotEditableHeaderItem(0, 3, tr("Part of variance") + "\n(" + tr("Threshold") + QString(" : %1 %").arg(ResourceMap::GetAsScalar("FunctionalChaosSobolIndices-VariancePartThreshold") * 100) + ")");
+      tableModel->setNotEditableHeaderItem(0, 2, tr("Part of variance") + "\n(" + tr("Threshold") + QString(" : %1 %").arg(ResourceMap::GetAsScalar("FunctionalChaosSobolIndices-VariancePartThreshold") * 100) + ")");
 
       // first coefficient
       tableModel->setNotEditableItem(1, 0, indices[0]);
       tableModel->setNotEditableItem(1, 1, enumerateFunction(indices[0]).__str__().c_str());
-      tableModel->setNotEditableItem(1, 2, coefficients(0, outputIndex));
-      tableModel->setNotEditableItem(1, 3, "-");
+      tableModel->setNotEditableItem(1, 2, "-");
 
       // part of variance
       Scalar varPartSum = 0;
@@ -267,12 +265,11 @@ void FunctionalChaosResultWindow::buildInterface()
 
         tableModel->setNotEditableItem(i + 2, 0, varianceOrder[i].first);
         tableModel->setNotEditableItem(i + 2, 1, multiIndices.__str__().c_str());
-        tableModel->setNotEditableItem(i + 2, 2, coefficients(i + 1, outputIndex));
-        tableModel->setNotEditableItem(i + 2, 3, QString("%1 %").arg(varianceOrder[i].second * 100, 0, 'f', 2));
+        tableModel->setNotEditableItem(i + 2, 2, QString("%1 %").arg(varianceOrder[i].second * 100, 0, 'f', 2));
         varPartSum += varianceOrder[i].second * 100;
       }
       tableModel->setNotEditableHeaderItem(tableModel->rowCount(), 0, tr("Sum"));
-      tableModel->setNotEditableItem(tableModel->rowCount() - 1, 3, QString("%1 %").arg(varPartSum, 0, 'f', 2));
+      tableModel->setNotEditableItem(tableModel->rowCount() - 1, 2, QString("%1 %").arg(varPartSum, 0, 'f', 2));
 
       tableView->resizeToContents();
       varStackedWidget->addWidget(tableView);
@@ -314,8 +311,8 @@ void FunctionalChaosResultWindow::buildInterface()
   ResizableStackedWidget * plotsStackedWidget = new ResizableStackedWidget;
   connect(outputsListWidget, SIGNAL(currentRowChanged(int)), plotsStackedWidget, SLOT(setCurrentIndex(int)));
   MetaModelValidationResult fakeResu(result_.getMetaModelOutputSample(),
-                                     result_.getFunctionalChaosResult().getRelativeErrors(),
-                                     result_.getFunctionalChaosResult().getResiduals());
+                                     result_.getMeanSquaredError(),
+                                     result_.getR2Score());
   for (UnsignedInteger i = 0; i < nbOutputs; ++ i)
   {
     MetaModelValidationWidget * validationWidget = new MetaModelValidationWidget(fakeResu, result_.getOutputSample(), i, "", this);
