@@ -2,7 +2,7 @@
 /**
  *  @brief OTStudy
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -61,6 +61,15 @@ MeshWindow::MeshWindow(PhysicalModelItem * item, QWidget * parent)
 }
 
 
+MeshWindow::MeshWindow(DataFieldModelItem * item, QWidget * parent)
+  : SubWindow(item, parent)
+  , dataMeshItem_(item)
+{
+  connect(item, SIGNAL(meshChanged()), this, SLOT(updateTable()));
+  connect(item, SIGNAL(meshOverwritten()), this, SIGNAL(meshOverwritten()));
+  buildInterface();
+}
+
 void MeshWindow::buildInterface()
 {
   QVBoxLayout * mainLayout = new QVBoxLayout(this);
@@ -86,7 +95,7 @@ void MeshWindow::buildInterface()
 
   // fill in table
   tableModel_->setHorizontalHeaderLabels(headerLabels);
-  const MeshModel meshModel(meshItem_->getPhysicalModel().getMeshModel());
+  const MeshModel meshModel = getMeshModel();
   const Variable param(meshModel.getIndexParameters()[0]);
   tableModel_->setItem(0, 0, new QStandardItem(QString::fromUtf8(param.getName().c_str())));
   tableModel_->setItem(0, 1, new QStandardItem(QString::fromUtf8(param.getDescription().c_str())));
@@ -113,18 +122,20 @@ void MeshWindow::buildInterface()
   isRegularLabel_ = new QLabel(tr("Regular mesh : %1").arg(meshModel.getMesh().isRegular() ? tr("Yes") : tr("No")));
   groupBoxLayout->addWidget(isRegularLabel_, 1, 0);
 
+  // Error message if mesh gets overwritten
+  errorMessageLabel_ = new TemporaryLabel;
+  groupBoxLayout->addWidget(errorMessageLabel_, 2, 0);
   mainLayout->addWidget(groupBox);
 
+  connect(this, &MeshWindow::meshOverwritten, [ = ] ()
+  {
+    errorMessageLabel_->setTemporaryErrorMessage(tr("Warning: Specified mesh is incompatbile and has been reset."));
+  });
+
   // mesh display
   tabWidget_ = new QTabWidget;
   bool canUseParaview = false;
-// #ifdef PERSALYS_HAVE_PARAVIEW
-//   if (OTguiSubWindow::SupportsOpenGL_3_2())
-//   {
-//     addParaviewWidgetsTabs();
-//     canUseParaview = true;
-//   }
-// #endif
+
   if (!canUseParaview)
   {
     addWidgetsTabs();
@@ -147,18 +158,21 @@ void MeshWindow::resizeEvent(QResizeEvent* event)
 
 void MeshWindow::editMesh()
 {
-  MeshDefinitionWizard wizard(meshItem_->getPhysicalModel().getMeshModel(), this);
+  MeshDefinitionWizard wizard(getMeshModel(), (Bool)dataMeshItem_, this);
   if (wizard.exec())
   {
     MeshModel meshModel(wizard.getMesh());
-    meshItem_->getPhysicalModel().setMeshModel(meshModel);
+    if (meshItem_)
+      meshItem_->getPhysicalModel().setMeshModel(meshModel);
+    if (dataMeshItem_)
+      dataMeshItem_->getDataFieldModel().setMeshModel(meshModel);
   }
 }
 
 
 void MeshWindow::updateTable()
 {
-  const MeshModel meshModel(meshItem_->getPhysicalModel().getMeshModel());
+  const MeshModel meshModel = getMeshModel();
   const Variable param(meshModel.getIndexParameters()[0]);
   tableModel_->setData(tableModel_->index(0, 0), param.getName().c_str());
   tableModel_->setData(tableModel_->index(0, 1), param.getDescription().c_str());
@@ -172,7 +186,7 @@ void MeshWindow::updateTable()
 
 void MeshWindow::updateModel(QStandardItem *item)
 {
-  MeshModel meshModel(meshItem_->getPhysicalModel().getMeshModel());
+  MeshModel meshModel(getMeshModel());
   Variable param(meshModel.getIndexParameters()[0]);
   if (item->column() == 0)
     param.setName(item->text().toStdString());
@@ -181,16 +195,31 @@ void MeshWindow::updateModel(QStandardItem *item)
   VariableCollection coll;
   coll.add(param);
   meshModel.setIndexParameters(coll);
-  meshItem_->getPhysicalModel().blockNotification("MeshItem");
-  meshItem_->getPhysicalModel().setMeshModel(meshModel);
-  meshItem_->getPhysicalModel().blockNotification();
+  if (meshItem_)
+  {
+    meshItem_->getPhysicalModel().blockNotification("MeshItem");
+    meshItem_->getPhysicalModel().setMeshModel(meshModel);
+    meshItem_->getPhysicalModel().blockNotification();
+  }
+  else if (dataMeshItem_)
+  {
+    // notifications are blocked to avoid infinite loop
+    dataMeshItem_->getDataFieldModel().blockNotification("DataMeshItem");
+    // but setting mesh model implies meshChanged signal which is connected to
+    // DataFieldModelWindow::updateProcessSample and mesh can be overwritten there if not compatible
+    // if so we need to catch notify("meshOverwritten") to set errorMessageLabel_ warning
+    dataMeshItem_->getDataFieldModel().setMeshModel(meshModel);
+    dataMeshItem_->getDataFieldModel().blockNotification();
+  }
   updatePlot();
+  // Need table update in case mesh gets overwritten
+  updateTable();
 }
 
 
 void MeshWindow::updatePlot()
 {
-  MeshModel meshModel(meshItem_->getPhysicalModel().getMeshModel());
+  MeshModel meshModel(getMeshModel());
 
   // update nodes table
   Sample sample(meshModel.getMesh().getVertices());
@@ -207,44 +236,6 @@ void MeshWindow::updatePlot()
   meshPlot_->plotCurve(sample, QPen(Qt::black, 2), QwtPlotCurve::Lines, new QwtSymbol(QwtSymbol::XCross, Qt::red, QPen(Qt::red), QSize(7, 7)));
 }
 
-// void MeshWindow::addParaviewWidgetsTabs()
-// {
-//   // graph
-//   WidgetBoundToDockWidget * mainWidget = new WidgetBoundToDockWidget(this);
-//   QVBoxLayout * mainWidgetLayout = new QVBoxLayout(mainWidget);
-//
-//   PVXYChartViewWidget * plotWidget = new PVXYChartViewWidget(this, PVServerManagerSingleton::Get());
-// //   plotWidget->setData(designOfExperiment_.getInputSample(), Qt::blue);
-//   mainWidgetLayout->addWidget(plotWidget);
-//
-//   // scatter plots setting widget
-//   PVXYChartSettingWidget * settingWidget = new PVXYChartSettingWidget(plotWidget,
-//       Sample(),
-//       Sample(),
-//       Sample(),
-//       Sample(),
-//       Sample(),
-//       Sample(),
-//       PVXYChartSettingWidget::NoType,
-//       this);
-//   mainWidget->setDockWidget(settingWidget);
-//
-//   tabWidget_->addTab(plotWidget, tr("Mesh"));
-//
-//   // table
-//   QWidget * tableView_ = new QWidget;
-//   QVBoxLayout * tableViewLayout = new QVBoxLayout(tableView_);
-//
-//   // with paraview the table is always shown in order to use the selection behavior
-//   PVSpreadSheetViewWidget * pvSpreadSheetWidget = new PVSpreadSheetViewWidget(this, PVServerManagerSingleton::Get());
-// //   pvSpreadSheetWidget->setData(designOfExperiment_.getSample());
-//   connect(getItem(), SIGNAL(dataExportRequested()), pvSpreadSheetWidget, SLOT(exportData()));
-//
-//   tableViewLayout->addWidget(pvSpreadSheetWidget);
-//
-//   tabWidget_->addTab(tableView_, tr("Table"));
-// }
-
 
 void MeshWindow::addWidgetsTabs()
 {
@@ -252,9 +243,6 @@ void MeshWindow::addWidgetsTabs()
   scrollArea->setWidgetResizable(true);
   // Mesh
   meshPlot_ = new PlotWidget;
-//   meshPlot->plotCurve();
-//   meshPlot_->setTitle(tr("Number of nodes = ") + " ");
-//   meshPlot_->setAxisTitle(QwtPlot::xBottom, "time");
 
   // Graph Setting
   SimpleGraphSetting * graphSetting = new SimpleGraphSetting(meshPlot_, this);
@@ -264,7 +252,6 @@ void MeshWindow::addWidgetsTabs()
 
   // nodes
   nodesView_ = new ExportableTableView;
-//   connect(getItem(), SIGNAL(dataExportRequested()), nodesView, SLOT(exportData()));
   nodesView_->setSortingEnabled(true);
   nodesModel_ = new SampleTableModel(Sample(), nodesView_);
 
@@ -277,4 +264,14 @@ void MeshWindow::addWidgetsTabs()
   tabWidget_->addTab(nodesView_, tr("Nodes"));
   updatePlot();
 }
+
+MeshModel MeshWindow::getMeshModel() const
+{
+  if (meshItem_)
+    return meshItem_->getPhysicalModel().getMeshModel();
+  else if (dataMeshItem_)
+    return dataMeshItem_->getDataFieldModel().getMeshModel();
+  else
+    throw InvalidArgumentException(HERE) << "MeshWindow::getMeshModel : cannot get MeshModel";
+}
 }
