@@ -2,7 +2,7 @@
 /**
  *  @brief Helper
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,10 +24,13 @@
 #include "persalys/LimitStateItem.hxx"
 #include "persalys/PhysicalModelDiagramItem.hxx"
 #include "persalys/DataModelDiagramItem.hxx"
+#include "persalys/DataFieldModelDiagramItem.hxx"
+#include "persalys/DataFieldModelDefinitionItem.hxx"
 
 #include "persalys/StudyWindow.hxx"
 #include "persalys/LimitStateWindow.hxx"
 #include "persalys/DataModelDiagramWindow.hxx"
+#include "persalys/DataFieldModelDiagramWindow.hxx"
 #include "persalys/PhysicalModelDiagramWindow.hxx"
 #include "persalys/FieldModelDiagramWindow.hxx"
 #include "persalys/SymbolicPhysicalModelWindow.hxx"
@@ -45,9 +48,11 @@
 
 #include "persalys/ObservationsWindow.hxx"
 #include "persalys/DataModelWindow.hxx"
+#include "persalys/DataFieldModelWindow.hxx"
 
 #include "persalys/DesignOfExperimentWindow.hxx"
 #include "persalys/DataAnalysisResultWindow.hxx"
+#include "persalys/QuantileAnalysisResultWindow.hxx"
 #include "persalys/ModelEvaluationResultWindow.hxx"
 #include "persalys/OptimizationResultWindow.hxx"
 #include "persalys/MultiObjectiveOptimizationResultWindow.hxx"
@@ -83,6 +88,7 @@
 #include "persalys/MetaModelExportWizard.hxx"
 #include "persalys/CopulaInferenceWizard.hxx"
 #include "persalys/CalibrationAnalysisWizard.hxx"
+#include "persalys/QuantileAnalysisWizard.hxx"
 
 #include <QDebug>
 
@@ -92,7 +98,7 @@ namespace PERSALYS
 SubWindow * WindowFactory::GetWindow(Item *item, QWidget *parent)
 {
   SubWindow * window = 0;
-
+  const QString itemType = item->data(Qt::UserRole).toString();
   // if study item
   if (StudyItem * studyItem = dynamic_cast<StudyItem *>(item))
   {
@@ -113,6 +119,12 @@ SubWindow * WindowFactory::GetWindow(Item *item, QWidget *parent)
   {
     window = GetDesignOfExperimentWindow(dmItem, parent);
   }
+  // if field data model item
+  else if (DataFieldModelItem * fdmItem = dynamic_cast<DataFieldModelItem *>(item))
+  {
+    window = GetDataFieldModelWindow(fdmItem, parent);
+  }
+
   return window;
 }
 
@@ -184,6 +196,29 @@ SubWindow * WindowFactory::GetPhysicalModelWindow(PhysicalModelItem *item, QWidg
 }
 
 
+SubWindow * WindowFactory::GetDataFieldModelWindow(DataFieldModelItem *item, QWidget *parent)
+{
+  // if diagram item
+  if (DataFieldModelDiagramItem * dmDiagramItem = dynamic_cast<DataFieldModelDiagramItem *>(item))
+  {
+    return new DataFieldModelDiagramWindow(dmDiagramItem, parent);
+  }
+
+  // if model definition item
+  const QString itemType = item->data(Qt::UserRole).toString();
+  if (itemType == "DataFieldModelDefinitionItem")
+  {
+    return new DataFieldModelWindow(item, parent);
+  }
+  else if (itemType == "DataMeshItem")
+  {
+    return new MeshWindow(item, parent);
+  }
+
+  return 0;
+}
+
+
 SubWindow * WindowFactory::GetDesignOfExperimentWindow(DesignOfExperimentItem *item, QWidget *parent)
 {
   // if diagram item
@@ -277,6 +312,10 @@ AnalysisWizard* WindowFactory::GetAnalysisWizard(const Analysis& analysis, const
   {
     wizard = new CalibrationAnalysisWizard(analysis, isGeneralWizard, parent);
   }
+  else if (analysisType == "QuantileAnalysis")
+  {
+    wizard = new QuantileAnalysisWizard(analysis, parent);
+  }
   else
   {
     qDebug() << "Error: In GetAnalysisWizard: analysisType " << analysisType << " not recognized.\n";
@@ -289,7 +328,6 @@ AnalysisWizard* WindowFactory::GetAnalysisWizard(const Analysis& analysis, const
 SubWindow* WindowFactory::GetAnalysisWindow(AnalysisItem* item, QWidget * parent)
 {
   const QString analysisType = item->data(Qt::UserRole).toString();
-
   if (analysisType == "DesignOfExperimentDefinitionItem")
     return new DesignOfExperimentInputWindow(item, parent);
 
@@ -329,6 +367,10 @@ SubWindow* WindowFactory::GetAnalysisWindow(AnalysisItem* item, QWidget * parent
   {
     resultWindow = new FieldCentralTendencyResultWindow(item, parent);
   }
+  else if (analysisType == "FieldKarhunenLoeveAnalysis")
+  {
+    resultWindow = new DataFieldAnalysisResultWindow(item, parent);
+  }
   else if (analysisType == "TaylorExpansionMomentsAnalysis")
   {
     resultWindow = new TaylorExpansionMomentsResultWindow(item, parent);
@@ -386,6 +428,10 @@ SubWindow* WindowFactory::GetAnalysisWindow(AnalysisItem* item, QWidget * parent
     // ImportedDesignOfExperiment ProbabilisticDesignOfExperiment
     resultWindow = new DesignOfExperimentWindow(item, parent);
   }
+  else if (analysisType == "QuantileAnalysis")
+  {
+    resultWindow = new QuantileAnalysisResultWindow(item, parent);
+  }
   else
   {
     qDebug() << "Error: In WindowFactory::GetAnalysisWindow: analysisType " << analysisType << " not recognized.\n";
