@@ -62,6 +62,7 @@
 #include <QMenu>
 #include <QAction>
 #include <QPainterPath>
+#include <QStyledItemDelegate>
 
 #include <cmath>
 
@@ -85,8 +86,35 @@ public:
   }
 };
 
+class PieChartLegendDelegate : public QStyledItemDelegate
+{
+public:
+  using QStyledItemDelegate::QStyledItemDelegate;
+  void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override
+  {
+    QVariant colorVar = index.data(Qt::DecorationRole);
+    QRect rect = option.rect;
+    int size = rect.height() * 0.6;
+    QRect colorRect(rect.left() + 2, rect.center().y() - size/2, size, size);
 
-PieChartView::PieChartView(const PointWithDescription& data, QWidget *parent)
+    if (colorVar.isValid())
+    {
+      QColor color = colorVar.value<QColor>();
+      painter->save();
+      painter->setBrush(color);
+      painter->setPen(Qt::NoPen);
+      painter->drawRect(colorRect);
+      painter->restore();
+    }
+
+    QStyleOptionViewItem opt(option);
+    opt.rect.setLeft(colorRect.right() + 6);
+
+    QStyledItemDelegate::paint(painter, opt, index);
+  }
+};
+
+PieChartView::PieChartView(const PointWithDescription& values, QWidget *parent)
   : QAbstractItemView(parent)
   , margin_(8)
   , totalSize_(200)
@@ -106,8 +134,10 @@ PieChartView::PieChartView(const PointWithDescription& data, QWidget *parent)
   setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
   setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
+  setItemDelegate(new PieChartLegendDelegate(this));
+
   // set model
-  setData(data);
+  setData(values);
 
   // context menu
   setContextMenuPolicy(Qt::CustomContextMenu);
@@ -117,17 +147,17 @@ PieChartView::PieChartView(const PointWithDescription& data, QWidget *parent)
 
 void PieChartView::setData(const PointWithDescription& valuesAndDescription)
 {
-  PointWithDescription data(valuesAndDescription);
+  PointWithDescription values(valuesAndDescription);
 
   // check
-  UnsignedInteger size = data.getSize();
+  UnsignedInteger size = values.getSize();
   if (size == 0)
   {
     qDebug() << "In PieChartView::setData: no data";
     throw std::exception();
   }
 
-  Scalar l1Norm = data.norm1();
+  Scalar l1Norm = values.norm1();
   if (l1Norm == .0)
   {
     qDebug() << "In PieChartView::setData: norm is null";
@@ -137,13 +167,13 @@ void PieChartView::setData(const PointWithDescription& valuesAndDescription)
   // normalize
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    data[i] /= l1Norm;
-    data[i] *= 100;
+    values[i] /= l1Norm;
+    values[i] *= 100;
   }
 
   // colors
   QVector<QColor> colors;
-  colors = generateSegmentsColors((int)data.getSize());
+  colors = generateSegmentsColors((int)values.getSize());
 
   // model
   PieChartModel * standardItemModel = new PieChartModel(size, 2, this);
@@ -153,7 +183,7 @@ void PieChartView::setData(const PointWithDescription& valuesAndDescription)
 
   for (UnsignedInteger i = 0; i < size; ++i)
   {
-    const QString text = QString::fromUtf8(data.getDescription()[i].c_str());
+    const QString text = QString::fromUtf8(values.getDescription()[i].c_str());
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
     const int textWidth = fm.horizontalAdvance(text);
 #else
@@ -163,9 +193,9 @@ void PieChartView::setData(const PointWithDescription& valuesAndDescription)
       maxTextWidth = textWidth;
 
     standardItemModel->setData(standardItemModel->index(i, 0, QModelIndex()), text);
-    standardItemModel->setData(standardItemModel->index(i, 1, QModelIndex()), QString::number(data[i]));
+    standardItemModel->setData(standardItemModel->index(i, 1, QModelIndex()), QString::number(values[i]));
     standardItemModel->setData(standardItemModel->index(i, 0, QModelIndex()), colors[i], Qt::DecorationRole);
-    totalValue_ += data[i];
+    totalValue_ += values[i];
     ++validItems_;
   }
   setModel(standardItemModel);
@@ -435,8 +465,8 @@ void PieChartView::draw(QPainter& painter)
 #else
   QBrush background = viewOptions().palette.base();
   QPen foreground(viewOptions().palette.color(QPalette::WindowText));
-#endif  
- 
+#endif
+
   painter.setRenderHint(QPainter::Antialiasing);
   painter.setPen(foreground);
 
