@@ -2,7 +2,7 @@
 /**
  *  @brief QwtPlot for all the graphics of the interface
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -590,19 +590,26 @@ void PlotWidget::clear()
 
 void PlotWidget::replot()
 {
+  changeXLabelOrientation();
   QwtPlot::replot();
   emit plotChanged();
 }
 
-
 void PlotWidget::setXLabelOrientation(int orientation)
 {
   // orientation == 0 : Horizontal
   // orientation == 1 : Slanting
   // orientation == 2 : Vertical
 
-  setAxisLabelAlignment(QwtPlot::xBottom, orientation == 0 ? Qt::AlignBottom : Qt::AlignLeft);
-  const Scalar angle = orientation * -45.;
+  xLabelOrientation_ = orientation;
+  changeXLabelOrientation();
+}
+
+void PlotWidget::changeXLabelOrientation()
+{
+
+  setAxisLabelAlignment(QwtPlot::xBottom, xLabelOrientation_ == 0 ? Qt::AlignBottom : Qt::AlignLeft);
+  const Scalar angle = xLabelOrientation_ * -45.;
   setAxisLabelRotation(QwtPlot::xBottom, angle);
 }
 
